"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseProj_1 = require("./baseProj");
const fs_i_1 = require("fs-i");
const fs_extra_1 = require("fs-extra");
const globalData_1 = require("../model/globalData");
class NodeProj extends baseProj_1.BaseProj {
    getQuestions() {
        let questionList = [
            {
                name: "needDocs",
                type: "list",
                message: "是否需要有开发文档",
                default: "否",
                choices: ["是", "否"]
            },
            {
                name: "unittest",
                type: "list",
                message: "是否需要创建单元测试？",
                default: "否",
                choices: ["是", "否"]
            }
        ];
        return questionList;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            let answer = yield this.getAnswers();
            let projPath = `${process.cwd()}/${globalData_1.GlobalData.projectName}`;
            if (answer.needDocs === "是") {
                this.addDocs(projPath);
            }
            if (answer.unittest === "是") {
                this.addUnitTest(projPath);
            }
        });
    }
    addDocs(path) {
        return __awaiter(this, void 0, void 0, function* () {
            {
                let file = `${path}/package.json`;
                let fileContent = yield fs_i_1.readFileUtf8(file);
                let json = JSON.parse(fileContent);
                json.devDependencies["typedoc"] = "^0.9.0";
                json.devDependencies["typedoc-format"] = "^1.0.2";
                json.scripts["docs"] = "typedoc --out docs src --module commonjs --hideGenerator && node ./tools/formatDocs.js";
                json.scripts["build"] = "npm run clean && npm run tsBuild && npm run docs";
                fileContent = JSON.stringify(json, null, 2);
                yield fs_extra_1.writeFileSync(file, fileContent);
            }
        });
    }
    addUnitTest(path) {
        return __awaiter(this, void 0, void 0, function* () {
            {
                let file = `${path}/package.json`;
                let fileContent = yield fs_i_1.readFileUtf8(file);
                let json = JSON.parse(fileContent);
                json.devDependencies["@types/chai"] = "^4.0.5";
                json.devDependencies["chai"] = "^4.1.2";
                json.devDependencies["@types/mocha"] = "^2.2.44";
                json.devDependencies["mocha"] = "^4.0.1";
                json.devDependencies["coveralls"] = "^3.0.0";
                json.devDependencies["nyc"] = "^11.3.0";
                json.devDependencies["source-map-support"] = "^0.5.0";
                json.scripts["test"] = "nyc mocha -t 5000";
                json.scripts["test-nyc"] = "nyc npm test && nyc report --reporter=text-lcov | coveralls";
                json["nyc"] = {
                    include: ["src/**/*.ts"],
                    extension: [".ts"],
                    require: ["ts-node/register"],
                    sourceMap: true,
                    instrument: true
                };
                fileContent = JSON.stringify(json, null, 2);
                yield fs_extra_1.writeFileSync(file, fileContent);
            }
            {
                let file = `${path}/.travis.yml`;
                let fileContent = yield fs_i_1.readFileUtf8(file);
                fileContent = fileContent.replace(/script\s*:/, (w, a, b, c, d) => {
                    return (w +
                        `
  - npm run test`);
                });
                fileContent = fileContent.replace(/after_script\s*:/, (w, a, b, c, d) => {
                    return (w +
                        `
  - npm run test-nyc`);
                });
                fileContent = fileContent.replace(/deploy\s*:/, (w, a, b, c, d) => {
                    return (w +
                        `
  - provider: pages
    skip_cleanup: true
    github_token: $GITHUB_TOKEN
    local_dir: docs
    on:
      branch: master
`);
                });
                yield fs_extra_1.writeFileSync(file, fileContent);
            }
            {
                let testPath = `${path}/test`;
                yield fs_i_1.mkdirs(testPath);
                yield fs_extra_1.writeFileSync(`${testPath}/mocha.opts`, `
--require ts-node/register
--require source-map-support/register
--full-trace
--bail
test/**/*.test.ts
      `.trim());
                yield fs_extra_1.writeFileSync(`${testPath}/index.test.ts`, `
import { expect } from "chai";
import "mocha";
import { add } from "../src/index";

describe("index", function() {
  before(async () => {});
  after(async () => {});

  it("add should be success", async () => {
    expect(add(1, 2)).to.equal(3);
  });
});   
      `.trim());
            }
        });
    }
}
exports.NodeProj = NodeProj;
//# sourceMappingURL=nodeProj.js.map